@@ -24,7 +24,7 @@
 
 #include "utils.h"
 #include "kcalprefs.h"
-#include "helper_p.h"
+
 
 #include <Collection>
 #include <CollectionDialog>
@@ -65,6 +65,7 @@
 #include <QModelIndex>
 #include <QPointer>
 #include <QFileDialog>
+#include <QUrlQuery>
 
 #include <boost/bind.hpp>
 #include "calendarsupport_debug.h"
@@ -631,7 +632,8 @@ QString CalendarSupport::displayName(Akonadi::ETMCalendar *calendar, const Akona
 
         if (!ownerStr.isEmpty()) {
             const int atChar = ownerStr.lastIndexOf(QLatin1Char('@'));
-            ownerStr = ownerStr.left(atChar);
+            if (atChar >= 0)
+                ownerStr.truncate(atChar);
             if (nameStr.isEmpty()) {
                 return i18nc("%1 is folder owner name, %2 is folder contents",
                              "%1's Google %2", ownerStr, typeStr);
